Choo-Siow Heteroskedastic - Cupid Matching

Skip to content

# `choo_siow_heteroskedastic` module

The components of the derivative of the entropy for the Choo and Siow fully heteroskedastic model.

We normalize the standard error for X=1 at 1, and we estimate the standard errors for all other types on the X side and for all types on the Y side.

## `e0_choo_siow_heteroskedastic(muhat)`

Returns the values of the parameter-independent part e_0
for the Choo and Siow heteroskedastic model; we normalized \sigma_1=1

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`muhat` | `Matching` | a Matching | required

Returns:

Type | Description
--- | ---
`np.ndarray` | the (X,Y) matrix of the parameter-independent part
`np.ndarray` | of the first derivative of the entropy

Source code in `cupid_matching/choo_siow_heteroskedastic.py`

    16
    17
    18
    19
    20
    21
    22
    23
    24
    25
    26
    27
    28
    29
    30
    31
    32
    33
    def e0_choo_siow_heteroskedastic(muhat: Matching) -> np.ndarray:
        """Returns the values of the parameter-independent part $e_0$
        for the Choo and Siow heteroskedastic model;
        we normalized $\\sigma_1=1$

        Args:
            muhat: a Matching

        Returns:
            the (X,Y) matrix of the parameter-independent part
            of the first derivative of the entropy
        """
        muxy, mux0, *_ = muhat.unpack()
        mu1y = muxy[0, :]
        mu10 = mux0[0]
        e0_vals = np.zeros_like(muxy)
        e0_vals[0, :] = -np.log(mu1y / mu10)
        return e0_vals

## `e0_derivative_mu_heteroskedastic(muhat)`

Returns the derivatives of the parameter-independent part e_0
wrt \mu
for the Choo and Siow heteroskedastic model; we normalized \sigma_1=1

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`muhat` | `Matching` | a Matching | required

Returns:

Type | Description
--- | ---
`ThreeArrays` | the parameter-independent part of the hessian of the entropy
`ThreeArrays` | wrt (\mu, \mu) .

Source code in `cupid_matching/choo_siow_heteroskedastic.py`

    36
    37
    38
    39
    40
    41
    42
    43
    44
    45
    46
    47
    48
    49
    50
    51
    52
    53
    54
    55
    56
    57
    58
    59
    60
    61
    62
    def e0_derivative_mu_heteroskedastic(
        muhat: Matching,
    ) -> ThreeArrays:
        """Returns the derivatives of the parameter-independent part $e_0$
        wrt $\\mu$ for the Choo and Siow heteroskedastic model;
        we normalized $\\sigma_1=1$

        Args:
            muhat: a Matching

        Returns:
            the parameter-independent part of the hessian of the entropy
            wrt $(\\mu, \\mu)$.
        """
        muxy, mux0, *_ = muhat.unpack()
        X, Y = muxy.shape
        mu1y = muxy[0, :]
        mu10 = mux0[0]
        hess_x = np.zeros((X, Y, Y))
        hess_y = np.zeros((X, Y, X))
        hess_xy = np.zeros((X, Y))
        der_log1y = 1.0 / mu1y
        der_log10 = 1.0 / mu10
        for y in range(Y):
            hess_x[0, y, :] = -der_log10
            hess_xy[0, y] = -der_log1y[y] - der_log10
        return hess_x, hess_y, hess_xy

## `e0_derivative_r_heteroskedastic(muhat)`

Returns the derivatives of the parameter-independent part e_0
wrt r
for the Choo and Siow heteroskedastic model; we normalized \sigma_1=1

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`muhat` | `Matching` | a Matching | required

Returns:

Type | Description
--- | ---
`TwoArrays` | the parameter-independent part of the hessian of the entropy
`TwoArrays` | wrt (\mu,r) .

Source code in `cupid_matching/choo_siow_heteroskedastic.py`

    65
    66
    67
    68
    69
    70
    71
    72
    73
    74
    75
    76
    77
    78
    79
    80
    81
    82
    83
    84
    85
    86
    87
    def e0_derivative_r_heteroskedastic(
        muhat: Matching,
    ) -> TwoArrays:
        """Returns the derivatives of the parameter-independent part $e_0$
        wrt $r$ for the Choo and Siow heteroskedastic model;
        we normalized $\\sigma_1=1$

        Args:
            muhat: a Matching

        Returns:
            the parameter-independent part of the hessian of the entropy
            wrt $(\\mu,r)$.
        """
        muxy, mux0, *_ = muhat.unpack()
        X, Y = muxy.shape
        mu10 = mux0[0]
        hess_n = np.zeros((X, Y))
        hess_m = np.zeros((X, Y))
        der_log10 = 1.0 / mu10
        for y in range(Y):
            hess_n[0, y] = der_log10
        return hess_n, hess_m

## `e_choo_siow_heteroskedastic(muhat)`

Returns the values of the parameter-dependent part e
for the Choo and Siow heteroskedastic model; we normalized \sigma_1=1

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`muhat` | `Matching` | a Matching | required

Returns:

Type | Description
--- | ---
`np.ndarray` | the (X,Y,X+Y-1) parameter-dependent part of the hessian of the entropy.

Source code in `cupid_matching/choo_siow_heteroskedastic.py`

     96
     97
     98
     99
    100
    101
    102
    103
    104
    105
    106
    107
    108
    109
    110
    111
    112
    113
    114
    115
    116
    117
    118
    119
    120
    def e_choo_siow_heteroskedastic(muhat: Matching) -> np.ndarray:
        """Returns the values of the parameter-dependent part  $e$
        for the Choo and Siow heteroskedastic model;
        we normalized $\\sigma_1=1$

        Args:
            muhat: a Matching

        Returns:
            the (X,Y,X+Y-1) parameter-dependent part of the hessian of the entropy.
        """
        muxy, mux0, mu0y, *_ = muhat.unpack()
        X, Y = muxy.shape
        n_alpha = X + Y - 1

        e_vals = np.zeros((X, Y, n_alpha))
        i = 0
        for x in range(1, X):
            e_vals[x, :, i] = -np.log(muxy[x, :] / mux0[x])
            i += 1
        for y in range(Y):
            e_vals[:, y, i] = -np.log(muxy[:, y] / mu0y[y])
            i += 1

        return e_vals

## `e_derivative_mu_heteroskedastic(muhat)`

Returns the derivatives of the parameter-dependent part e
wrt \mu
for the Choo and Siow heteroskedastic model; we normalized \sigma_1=1

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`muhat` | `Matching` | a Matching | required

Returns:

Type | Description
--- | ---
`ThreeArrays` | the parameter-dependent part of the hessian of the entropy
`ThreeArrays` | wrt (\mu,\mu) .

Source code in `cupid_matching/choo_siow_heteroskedastic.py`

    123
    124
    125
    126
    127
    128
    129
    130
    131
    132
    133
    134
    135
    136
    137
    138
    139
    140
    141
    142
    143
    144
    145
    146
    147
    148
    149
    150
    151
    152
    153
    154
    155
    156
    157
    158
    159
    160
    161
    162
    163
    164
    165
    def e_derivative_mu_heteroskedastic(
        muhat: Matching,
    ) -> ThreeArrays:
        """Returns the derivatives of the parameter-dependent part $e$
        wrt $\\mu$ for the Choo and Siow heteroskedastic model;
        we normalized $\\sigma_1=1$

        Args:
            muhat: a Matching

        Returns:
            the parameter-dependent part of the hessian of the entropy
            wrt $(\\mu,\\mu)$.
        """
        muxy, mux0, mu0y, *_ = muhat.unpack()
        X, Y = muxy.shape
        n_alpha = X + Y - 1
        hess_x = np.zeros((X, Y, Y, n_alpha))
        hess_y = np.zeros((X, Y, X, n_alpha))
        hess_xy = np.zeros((X, Y, n_alpha))

        der_logxy = 1.0 / muxy
        der_logx0 = 1.0 / mux0
        der_log0y = 1.0 / mu0y
        i = 0
        for x in range(1, X):
            # derivatives wrt sigma_x
            dlogx0 = der_logx0[x]
            dlogxy = der_logxy[x, :]
            for y in range(Y):
                hess_x[x, y, :, i] = -dlogx0
                hess_xy[x, y, i] = -dlogxy[y] - dlogx0
            i += 1
        for y in range(Y):
            # derivatives wrt tau_y
            dlog0y = der_log0y[y]
            dlogxy = der_logxy[:, y]
            for x in range(X):
                hess_y[x, y, :, i] = -dlog0y
                hess_xy[x, y, i] = -dlogxy[x] - dlog0y
            i += 1

        return hess_x, hess_y, hess_xy

## `e_derivative_r_heteroskedastic(muhat)`

Returns the derivatives of the parameter-dependent part e
wrt r
for the Choo and Siow heteroskedastic model; we normalized \sigma_1=1

Parameters:

Name | Type | Description | Default
--- | --- | --- | ---
`muhat` | `Matching` | a Matching | required

Returns:

Type | Description
--- | ---
`TwoArrays` | the parameter-dependent part of the hessian of the entropy
`TwoArrays` | wrt r .

Source code in `cupid_matching/choo_siow_heteroskedastic.py`

    168
    169
    170
    171
    172
    173
    174
    175
    176
    177
    178
    179
    180
    181
    182
    183
    184
    185
    186
    187
    188
    189
    190
    191
    192
    193
    194
    195
    196
    197
    198
    199
    200
    201
    202
    203
    204
    def e_derivative_r_heteroskedastic(
        muhat: Matching,
    ) -> TwoArrays:
        """Returns the derivatives of the parameter-dependent part $e$
        wrt $r$ for the Choo and Siow heteroskedastic model;
        we normalized $\\sigma_1=1$

        Args:
            muhat: a Matching

        Returns:
            the parameter-dependent part of the hessian of the entropy
            wrt $r$.
        """
        muxy, mux0, mu0y, *_ = muhat.unpack()
        X, Y = muxy.shape
        n_alpha = X + Y - 1
        hess_n = np.zeros((X, Y, n_alpha))
        hess_m = np.zeros((X, Y, n_alpha))

        der_logx0 = 1.0 / mux0
        der_log0y = 1.0 / mu0y
        i = 0
        for x in range(1, X):
            # derivatives wrt sigma_x
            dlogx0 = der_logx0[x]
            for y in range(Y):
                hess_n[x, y, i] = dlogx0
            i += 1
        for y in range(Y):
            # derivatives wrt tau_y
            dlog0y = der_log0y[y]
            for x in range(X):
                hess_m[x, y, i] = dlog0y
            i += 1

        return hess_n, hess_m